assert_output

Function assert_output 

pub fn assert_output<E, T>(endpoint: E) -> E
where E: Endpoint<Output = T>,
An identity function for giving additional trait bound to an endpoint.alloc

This function is usually used in the implementation of library.