macro_rules! poll_result {
($e:expr) => { ... };
}Expand description
A helper macro for extracting the successful value of PollResult<T, E>.
macro_rules! poll_result {
($e:expr) => { ... };
}A helper macro for extracting the successful value of PollResult<T, E>.