Components for constructing asynchronous computations which will be returned from Endpoints.
The main trait in this module is Task.
This trait is an abstraction of asynchronous computations which will be returned from endpoints.
The role of this trait is very close to futures and hence its design intentionally resembles
Future. However, some differences are exist for specializing to the purpose of HTTP handling.
This trait does not provide any combinators for composing complicate computations.
Such combinations are usually performed indirectly by the endpoints or by wrapping the value of
Future.
Structs
- Abort
- A
Taskwhich will immediately abort with an error value ofE. - Context
- The contextual information during polling an task.
- Ready
- A
Taskwhich will immediately return a value ofT. - Task
Future - A helper struct which wraps a
Futureand provides the implementation ofTask.
Traits
- Into
Task - Trait representing the conversion to a
Task. - Task
- Trait representing the asynchronous computation after applying the endpoints.